@@ -1,6 +1,7 @@
 package library
 
 import (
+	"context"
 	"testing"
 	"time"
 
@@ -17,7 +18,7 @@ import (
 
 // GetKubeAPIServerOperatorConfigGeneration returns the current generation of the KubeApiServer/cluster resource.
 func GetKubeAPIServerOperatorConfigGeneration(t *testing.T, operatorClient *operatorclient.OperatorV1Client) int64 {
-	config, err := operatorClient.KubeAPIServers().Get("cluster", metav1.GetOptions{})
+	config, err := operatorClient.KubeAPIServers().Get(context.TODO(), "cluster", metav1.GetOptions{})
 	if errors.IsNotFound(err) {
 		return 0
 	}
@@ -36,7 +37,7 @@ func WaitForNextKubeAPIServerOperatorConfigGenerationToFinishProgressing(t *test
 
 	// wait for Available=true and Progressing=false to stop
 	err := wait.Poll(WaitPollInterval, WaitPollTimeout, func() (bool, error) {
-		config, err := client.KubeAPIServers().Get("cluster", metav1.GetOptions{})
+		config, err := client.KubeAPIServers().Get(context.TODO(), "cluster", metav1.GetOptions{})
 		if err != nil {
 			t.Log(err)
 			return false, nil
@@ -66,35 +67,3 @@ func WaitForNextKubeAPIServerOperatorConfigGenerationToFinishProgressing(t *test
 	})
 	require.NoError(t, err)
 }
-
-type KubeAPIServerOperatorStatusFunc func(cluster *operatorv1.KubeAPIServer) bool
-
-func WaitForKubeAPIServerOperatorStatus(t *testing.T, client operatorclient.OperatorV1Interface, f KubeAPIServerOperatorStatusFunc) (cluster *operatorv1.KubeAPIServer) {
-	err := wait.Poll(WaitPollInterval, WaitPollTimeout, func() (done bool, pollErr error) {
-		cluster, pollErr = client.KubeAPIServers().Get("cluster", metav1.GetOptions{})
-		if pollErr != nil {
-			return
-		}
-
-		if cluster == nil || !f(cluster) {
-			return
-		}
-
-		done = true
-		return
-	})
-
-	require.NoErrorf(t, err, "[WaitForKubeAPIServerOperatorStatus] wait.Poll returned error - %v", err)
-	require.NotNil(t, cluster)
-	return
-}
-
-func FindOperatorStatusCondition(conditions []operatorv1.OperatorCondition, conditionType string) *operatorv1.OperatorCondition {
-	for i := range conditions {
-		if conditions[i].Type == conditionType {
-			return &conditions[i]
-		}
-	}
-
-	return nil
-}
